#
# SPDX-FileCopyrightText: Copyright (c) 2025 provide.io llc. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
#

"""TODO: Add module docstring."""

from __future__ import annotations

"""OpenObserve integration defaults for Foundation configuration."""

# =================================
# OpenObserve Defaults
# =================================
DEFAULT_OPENOBSERVE_TIMEOUT = 30
DEFAULT_OPENOBSERVE_MAX_RETRIES = 3

__all__ = [
    "DEFAULT_OPENOBSERVE_MAX_RETRIES",
    "DEFAULT_OPENOBSERVE_TIMEOUT",
]

# 🧱🏗️🔚
