#
# SPDX-FileCopyrightText: Copyright (c) 2025 provide.io llc. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
#

"""TODO: Add module docstring."""

from __future__ import annotations

"""Optional integrations for Foundation.

This module contains integrations with external services and tools
that are not part of the core foundation library.
"""

__all__: list[str] = [
    # Available integrations (import on demand)
    # "openobserve",
]

# 🧱🏗️🔚
